# gridsome-transformer-docutils

[![Build Status](https://travis-ci.com/vberlier/gridsome-transformer-docutils.svg?branch=master)](https://travis-ci.com/vberlier/gridsome-transformer-docutils)
[![npm](https://img.shields.io/npm/v/gridsome-transformer-docutils.svg)](https://www.npmjs.com/package/gridsome-transformer-docutils)

> Docutils transformer for Gridsome.

This transformer parses [docutils xml documents](http://docutils.sourceforge.net/docs/ref/doctree.html) with [docutils-parser](https://github.com/vberlier/docutils-parser). This lets you load documentation generated by tools like [sphinx](http://www.sphinx-doc.org) as a Gridsome data source.

## Installation

You can install `gridsome-transformer-docutils` with your `npm` client of choice.

```bash
$ npm install --save-dev gridsome-transformer-docutils
```

## Usage

After installing the package as a development dependency, you can configure [@gridsome/source-filesystem](https://github.com/gridsome/gridsome/tree/master/packages/source-filesystem) to load your generated xml files.

```js
// gridsome.config.js

module.exports = {
  plugins: [
    {
      use: "@gridsome/source-filesystem",
      options: {
        typeName: "SphinxDocument",
        path: "sphinx/**/*.xml"
      }
    }
  ],
  templates: {
    SphinxDocument: "/:sourcePath_raw+"
  }
}
```

### Configuration

You can configure the transformer globally and/or for a specific filesystem source.

```js
// gridsome.config.js

module.exports = {
  plugins: [
    {
      use: "@gridsome/source-filesystem",
      options: {
        typeName: "SphinxDocument",
        path: "sphinx/**/*.xml",
        docutils: {
          // Options
        }
      }
    }
  ],
  transformers: {
    docutils: {
      // Global options
    }
  }
}
```

#### Options

- `basePath`

  Defaults to `'/'`. Specifies the path from where the [`sourcePath`](#fields) field of each document should be resolved.

- `plugins`

  Defaults to `[]`. An array of plugins passed to [docutils-parser](https://github.com/vberlier/docutils-parser) when parsing documents.

### Fields

In addition to the fields exposed by default by the source filesystem plugin, the transformer provides the generated nodes with two more fields:

- `root`

  The object returned by parsing the `content` field with [docutils-parser](https://github.com/vberlier/docutils-parser).

- `sourcePath`

  An array that reflects the original path of the file based on the document's source attribute. For example, the `sourcePath` field will be `['hello']` if you have a document with the following source attribute:

  ```xml
  <document source=".../example-project/docs/introduction/hello.rst">
  ```

  The value of the `sourcePath` field depends on the configured `basePath`. Setting the `basePath` to `'docs/'` would yield `['introduction', 'hello']` instead.

  The main purpose of the `sourcePath` field is to make it easy to route the document to the path originally generated by sphinx to avoid breaking internal references:

  ```js
  // gridsome.config.js

  module.exports = {
    // ...
    templates: {
      SphinxDocument: "/:sourcePath_raw+"
    }
  }
  ```

## Contributing

Contributions are welcome. This project uses [jest](https://jestjs.io/) for testing.

```bash
$ npm test
```

The code follows the [javascript standard](https://standardjs.com/) style guide.

```bash
$ npm run lint
```

---

License - [MIT](https://github.com/vberlier/gridsome-transformer-docutils/blob/master/LICENSE)
